fireworks.scripts.tests package — FireWorks 2.0.4 documentation

# fireworks.scripts.tests package

## Submodules

## fireworks.scripts.tests.test_lpad_run module

fireworks.scripts.tests.test_lpad_run.lp(capsys)

fireworks.scripts.tests.test_lpad_run.test_lpad_config_file_flags() → None

  Test lpad CLI throws errors on missing config file flags.

fireworks.scripts.tests.test_lpad_run.test_lpad_get_fws(capsys, lp, detail, expected_1, expected_2) → None

  Test lpad CLI get_fws command.

fireworks.scripts.tests.test_lpad_run.test_lpad_report_version(capsys, arg) → None

  Test lpad CLI version flag.

## fireworks.scripts.tests.test_mlaunch_run module

fireworks.scripts.tests.test_mlaunch_run.test_mlaunch_config_file_flags() → None

  Test mlaunch CLI throws errors on missing config file flags.

fireworks.scripts.tests.test_mlaunch_run.test_mlaunch_report_version(capsys, arg) → None

  Test mlaunch CLI version flag.

## fireworks.scripts.tests.test_qlaunch_run module

fireworks.scripts.tests.test_qlaunch_run.test_qlaunch_config_file_flags() → None

  Test qlaunch CLI throws errors on missing config file flags.

fireworks.scripts.tests.test_qlaunch_run.test_qlaunch_report_version(capsys, arg) → None

  Test qlaunch CLI version flag.

## fireworks.scripts.tests.test_rlaunch_run module

fireworks.scripts.tests.test_rlaunch_run.test_rlaunch_config_file_flags() → None

  Test rlaunch CLI throws errors on missing config file flags.

fireworks.scripts.tests.test_rlaunch_run.test_rlaunch_report_version(capsys, arg) → None

  Test rlaunch CLI version flag.

## Module contents